import Flutter
import attestr_flowx

public class AttestrFlowxDelegate: NSObject, AttestrFlowxEventProtocol {
    
    private var pendingResult: FlutterResult!

    static let FLOW_COMPLETE = 0
    static let FLOW_SKIP = 1
    static let FLOW_ERROR = 2
    
    public func launchFlow(options : Dictionary<String, Any>, result: @escaping FlutterResult){
        
        self.pendingResult = result
        
        let hs = options["hs"]
        let cl = options["cl"]
        let lc = options["lc"]
        let retry = options["retry"]
        let qr = options["qr"]
        
        let flow = AttestrFlowx().initialize(cl: cl, hs: hs, self)
        flow?.launch(lc: lc, retry: retry, qr: qr)
    }
    
    public func onFlowxSuccess(_ data: [String : AnyObject]) {

        let newData = [String : AnyObject]()
        newData["type"] = FLOW_COMPLETE

        let result = [String : AnyObject]()
        result["message"] = data["message"]

        newData["data"] = result
        pendingResult(newData as NSDictionary)
    }
    
    public func onFlowxSkip(_ data: [String : AnyObject]) {
        let newData = [String : AnyObject]()
        newData["type"] = FLOW_SKIP

        let result = [String : AnyObject]()
        result["message"] = data["message"]

        newData["data"] = result

        pendingResult(data as NSDictionary)
    }
    
    public func onFlowxError(_ data: [String : AnyObject]) {

        let newData = [String : AnyObject]()
        newData["type"] = FLOW_ERROR

        let result = [String : AnyObject]()
        result["message"] = data["message"]

        newData["data"] = result
        pendingResult(data as NSDictionary)
    }
    
}
